==> plantuml-libs-7.1.0.tgz: package/distribution/azure-4/Item/General/ServiceServiceHealth.md <==
# ServiceServiceHealth


```text
azure-4/Item/General/ServiceServiceHealth
```

```text
include('azure-4/Item/General/ServiceServiceHealth')
```



| Illustration | ServiceServiceHealth | ServiceServiceHealthCard | ServiceServiceHealthGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/General/ServiceServiceHealth.png) | ![illustration for ServiceServiceHealth](../../../azure-4/Item/General/ServiceServiceHealth.Local.png) | ![illustration for ServiceServiceHealthCard](../../../azure-4/Item/General/ServiceServiceHealthCard.Local.png) | ![illustration for ServiceServiceHealthGroup](../../../azure-4/Item/General/ServiceServiceHealthGroup.Local.png) |




## ServiceServiceHealth

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceServiceHealth
include('azure-4/Item/General/ServiceServiceHealth')

' renders the element
ServiceServiceHealth('ServiceServiceHealth', 'Service Service Health', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceServiceHealth
include('azure-4/Item/General/ServiceServiceHealth')

' renders the element
ServiceServiceHealth('ServiceServiceHealth', 'Service Service Health', 'an optional tech label')
@enduml
```

## ServiceServiceHealthCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceServiceHealthCard
include('azure-4/Item/General/ServiceServiceHealth')

' renders the element
ServiceServiceHealthCard('ServiceServiceHealthCard', 'Service Service Health Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceServiceHealthCard
include('azure-4/Item/General/ServiceServiceHealth')

' renders the element
ServiceServiceHealthCard('ServiceServiceHealthCard', 'Service Service Health Card', 'an optional description')
@enduml
```

## ServiceServiceHealthGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceServiceHealthGroup
include('azure-4/Item/General/ServiceServiceHealth')

' renders the element
ServiceServiceHealthGroup('ServiceServiceHealthGroup', 'Service Service Health Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceServiceHealthGroup
include('azure-4/Item/General/ServiceServiceHealth')

' renders the element
ServiceServiceHealthGroup('ServiceServiceHealthGroup', 'Service Service Health Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/azure-4/Item/General/ServiceServiceHealth.md <==
# ServiceServiceHealth


```text
azure-4/Item/General/ServiceServiceHealth
```

```text
include('azure-4/Item/General/ServiceServiceHealth')
```



| Illustration | ServiceServiceHealth | ServiceServiceHealthCard | ServiceServiceHealthGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/General/ServiceServiceHealth.png) | ![illustration for ServiceServiceHealth](../../../azure-4/Item/General/ServiceServiceHealth.Local.png) | ![illustration for ServiceServiceHealthCard](../../../azure-4/Item/General/ServiceServiceHealthCard.Local.png) | ![illustration for ServiceServiceHealthGroup](../../../azure-4/Item/General/ServiceServiceHealthGroup.Local.png) |




## ServiceServiceHealth

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceServiceHealth
include('azure-4/Item/General/ServiceServiceHealth')

' renders the element
ServiceServiceHealth('ServiceServiceHealth', 'Service Service Health', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceServiceHealth
include('azure-4/Item/General/ServiceServiceHealth')

' renders the element
ServiceServiceHealth('ServiceServiceHealth', 'Service Service Health', 'an optional tech label', 'an optional description')
@enduml
```

## ServiceServiceHealthCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceServiceHealthCard
include('azure-4/Item/General/ServiceServiceHealth')

' renders the element
ServiceServiceHealthCard('ServiceServiceHealthCard', 'Service Service Health Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceServiceHealthCard
include('azure-4/Item/General/ServiceServiceHealth')

' renders the element
ServiceServiceHealthCard('ServiceServiceHealthCard', 'Service Service Health Card', 'an optional description')
@enduml
```

## ServiceServiceHealthGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceServiceHealthGroup
include('azure-4/Item/General/ServiceServiceHealth')

' renders the element
ServiceServiceHealthGroup('ServiceServiceHealthGroup', 'Service Service Health Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceServiceHealthGroup
include('azure-4/Item/General/ServiceServiceHealth')

' renders the element
ServiceServiceHealthGroup('ServiceServiceHealthGroup', 'Service Service Health Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
